Struct DwAccess

struct DwAccess(3127)

The encodings of the constants used in the DW_AT_accessibility attribute.

See Section 7.9, Table 7.14.

Implementations

impl DwAccess

fn static_string(self: &Self) -> Option<&'static str>

impl Clone for DwAccess

fn clone(self: &Self) -> DwAccess

impl Copy for DwAccess

impl Debug for DwAccess

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Display for DwAccess

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result<(), Error>

impl Eq for DwAccess

impl Freeze for DwAccess

impl Hash for DwAccess

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl Ord for DwAccess

fn cmp(self: &Self, other: &DwAccess) -> Ordering

impl PartialEq for DwAccess

fn eq(self: &Self, other: &DwAccess) -> bool

impl PartialOrd for DwAccess

fn partial_cmp(self: &Self, other: &DwAccess) -> Option<Ordering>

impl RefUnwindSafe for DwAccess

impl Send for DwAccess

impl StructuralPartialEq for DwAccess

impl Sync for DwAccess

impl Unpin for DwAccess

impl UnsafeUnpin for DwAccess

impl UnwindSafe for DwAccess

impl<T> Any for DwAccess

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for DwAccess

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for DwAccess

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for DwAccess

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for DwAccess

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for DwAccess

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> ToString for DwAccess

fn to_string(self: &Self) -> String

impl<T, U> Into for DwAccess

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for DwAccess

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for DwAccess

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>