Struct DwAddr

struct DwAddr(3343)

The encodings of the constants used in the DW_AT_address_class attribute.

There is only one value that is common to all target architectures. See Section 7.13.

Implementations

impl DwAddr

fn static_string(self: &Self) -> Option<&'static str>

impl Clone for DwAddr

fn clone(self: &Self) -> DwAddr

impl Copy for DwAddr

impl Debug for DwAddr

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Display for DwAddr

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result<(), Error>

impl Eq for DwAddr

impl Freeze for DwAddr

impl Hash for DwAddr

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl Ord for DwAddr

fn cmp(self: &Self, other: &DwAddr) -> Ordering

impl PartialEq for DwAddr

fn eq(self: &Self, other: &DwAddr) -> bool

impl PartialOrd for DwAddr

fn partial_cmp(self: &Self, other: &DwAddr) -> Option<Ordering>

impl RefUnwindSafe for DwAddr

impl Send for DwAddr

impl StructuralPartialEq for DwAddr

impl Sync for DwAddr

impl Unpin for DwAddr

impl UnsafeUnpin for DwAddr

impl UnwindSafe for DwAddr

impl<T> Any for DwAddr

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for DwAddr

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for DwAddr

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for DwAddr

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for DwAddr

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for DwAddr

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> ToString for DwAddr

fn to_string(self: &Self) -> String

impl<T, U> Into for DwAddr

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for DwAddr

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for DwAddr

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>