Struct DwCfa

struct DwCfa(2283)

The opcode for a call frame instruction.

Section 7.24:

Call frame instructions are encoded in one or more bytes. The primary opcode is encoded in the high order two bits of the first byte (that is, opcode = byte >> 6). An operand or extended opcode may be encoded in the low order 6 bits. Additional operands are encoded in subsequent bytes.

Implementations

impl DwCfa

fn static_string(self: &Self) -> Option<&'static str>

impl Clone for DwCfa

fn clone(self: &Self) -> DwCfa

impl Copy for DwCfa

impl Debug for DwCfa

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Display for DwCfa

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result<(), Error>

impl Eq for DwCfa

impl Freeze for DwCfa

impl Hash for DwCfa

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl Ord for DwCfa

fn cmp(self: &Self, other: &DwCfa) -> Ordering

impl PartialEq for DwCfa

fn eq(self: &Self, other: &DwCfa) -> bool

impl PartialOrd for DwCfa

fn partial_cmp(self: &Self, other: &DwCfa) -> Option<Ordering>

impl RefUnwindSafe for DwCfa

impl Send for DwCfa

impl StructuralPartialEq for DwCfa

impl Sync for DwCfa

impl Unpin for DwCfa

impl UnsafeUnpin for DwCfa

impl UnwindSafe for DwCfa

impl<T> Any for DwCfa

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for DwCfa

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for DwCfa

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for DwCfa

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for DwCfa

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for DwCfa

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> ToString for DwCfa

fn to_string(self: &Self) -> String

impl<T, U> Into for DwCfa

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for DwCfa

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for DwCfa

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>