Struct DwDefaulted

struct DwDefaulted(3636)

The encodings of the constants used in the DW_AT_defaulted attribute.

See Section 7.20, Table 7.24.

Implementations

impl DwDefaulted

fn static_string(self: &Self) -> Option<&'static str>

impl Clone for DwDefaulted

fn clone(self: &Self) -> DwDefaulted

impl Copy for DwDefaulted

impl Debug for DwDefaulted

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Display for DwDefaulted

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result<(), Error>

impl Eq for DwDefaulted

impl Freeze for DwDefaulted

impl Hash for DwDefaulted

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl Ord for DwDefaulted

fn cmp(self: &Self, other: &DwDefaulted) -> Ordering

impl PartialEq for DwDefaulted

fn eq(self: &Self, other: &DwDefaulted) -> bool

impl PartialOrd for DwDefaulted

fn partial_cmp(self: &Self, other: &DwDefaulted) -> Option<Ordering>

impl RefUnwindSafe for DwDefaulted

impl Send for DwDefaulted

impl StructuralPartialEq for DwDefaulted

impl Sync for DwDefaulted

impl Unpin for DwDefaulted

impl UnsafeUnpin for DwDefaulted

impl UnwindSafe for DwDefaulted

impl<T> Any for DwDefaulted

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for DwDefaulted

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for DwDefaulted

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for DwDefaulted

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for DwDefaulted

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for DwDefaulted

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> ToString for DwDefaulted

fn to_string(self: &Self) -> String

impl<T, U> Into for DwDefaulted

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for DwDefaulted

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for DwDefaulted

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>