Struct DwLang

struct DwLang(3250)

The encodings of the constants used in the DW_AT_language attribute.

See Section 7.12, Table 7.17.

Implementations

impl DwLang

fn static_string(self: &Self) -> Option<&'static str>

impl DwLang

fn default_lower_bound(self: Self) -> Option<usize>

Get the default DW_AT_lower_bound for this language.

impl Clone for DwLang

fn clone(self: &Self) -> DwLang

impl Copy for DwLang

impl Debug for DwLang

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Display for DwLang

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result<(), Error>

impl Eq for DwLang

impl Freeze for DwLang

impl Hash for DwLang

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl Ord for DwLang

fn cmp(self: &Self, other: &DwLang) -> Ordering

impl PartialEq for DwLang

fn eq(self: &Self, other: &DwLang) -> bool

impl PartialOrd for DwLang

fn partial_cmp(self: &Self, other: &DwLang) -> Option<Ordering>

impl RefUnwindSafe for DwLang

impl Send for DwLang

impl StructuralPartialEq for DwLang

impl Sync for DwLang

impl Unpin for DwLang

impl UnsafeUnpin for DwLang

impl UnwindSafe for DwLang

impl<T> Any for DwLang

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for DwLang

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for DwLang

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for DwLang

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for DwLang

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for DwLang

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> ToString for DwLang

fn to_string(self: &Self) -> String

impl<T, U> Into for DwLang

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for DwLang

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for DwLang

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>