Struct DwLne

struct DwLne(3727)

The encodings for the extended opcodes for line number information.

See Section 7.22, Table 7.26.

Implementations

impl DwLne

fn static_string(self: &Self) -> Option<&'static str>

impl Clone for DwLne

fn clone(self: &Self) -> DwLne

impl Copy for DwLne

impl Debug for DwLne

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Display for DwLne

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result<(), Error>

impl Eq for DwLne

impl Freeze for DwLne

impl Hash for DwLne

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl Ord for DwLne

fn cmp(self: &Self, other: &DwLne) -> Ordering

impl PartialEq for DwLne

fn eq(self: &Self, other: &DwLne) -> bool

impl PartialOrd for DwLne

fn partial_cmp(self: &Self, other: &DwLne) -> Option<Ordering>

impl RefUnwindSafe for DwLne

impl Send for DwLne

impl StructuralPartialEq for DwLne

impl Sync for DwLne

impl Unpin for DwLne

impl UnsafeUnpin for DwLne

impl UnwindSafe for DwLne

impl<T> Any for DwLne

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for DwLne

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for DwLne

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for DwLne

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for DwLne

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for DwLne

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> ToString for DwLne

fn to_string(self: &Self) -> String

impl<T, U> Into for DwLne

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for DwLne

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for DwLne

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>