Struct DwLns

struct DwLns(3677)

The encodings for the standard opcodes for line number information.

See Section 7.22, Table 7.25.

Implementations

impl DwLns

fn static_string(self: &Self) -> Option<&'static str>

impl Clone for DwLns

fn clone(self: &Self) -> DwLns

impl Copy for DwLns

impl Debug for DwLns

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Display for DwLns

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result<(), Error>

impl Eq for DwLns

impl Freeze for DwLns

impl Hash for DwLns

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl Ord for DwLns

fn cmp(self: &Self, other: &DwLns) -> Ordering

impl PartialEq for DwLns

fn eq(self: &Self, other: &DwLns) -> bool

impl PartialOrd for DwLns

fn partial_cmp(self: &Self, other: &DwLns) -> Option<Ordering>

impl RefUnwindSafe for DwLns

impl Send for DwLns

impl StructuralPartialEq for DwLns

impl Sync for DwLns

impl Unpin for DwLns

impl UnsafeUnpin for DwLns

impl UnwindSafe for DwLns

impl<T> Any for DwLns

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for DwLns

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for DwLns

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for DwLns

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for DwLns

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for DwLns

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> ToString for DwLns

fn to_string(self: &Self) -> String

impl<T, U> Into for DwLns

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for DwLns

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for DwLns

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>