Struct DwOrd

struct DwOrd(3511)

The encodings of the constants used in the DW_AT_ordering attribute.

See Section 7.17, Table 7.17.

Implementations

impl DwOrd

fn static_string(self: &Self) -> Option<&'static str>

impl Clone for DwOrd

fn clone(self: &Self) -> DwOrd

impl Copy for DwOrd

impl Debug for DwOrd

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Display for DwOrd

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result<(), Error>

impl Eq for DwOrd

impl Freeze for DwOrd

impl Hash for DwOrd

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl Ord for DwOrd

fn cmp(self: &Self, other: &DwOrd) -> Ordering

impl PartialEq for DwOrd

fn eq(self: &Self, other: &DwOrd) -> bool

impl PartialOrd for DwOrd

fn partial_cmp(self: &Self, other: &DwOrd) -> Option<Ordering>

impl RefUnwindSafe for DwOrd

impl Send for DwOrd

impl StructuralPartialEq for DwOrd

impl Sync for DwOrd

impl Unpin for DwOrd

impl UnsafeUnpin for DwOrd

impl UnwindSafe for DwOrd

impl<T> Any for DwOrd

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for DwOrd

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for DwOrd

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for DwOrd

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for DwOrd

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for DwOrd

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> ToString for DwOrd

fn to_string(self: &Self) -> String

impl<T, U> Into for DwOrd

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for DwOrd

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for DwOrd

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>