Struct DwVis

struct DwVis(3168)

The encodings of the constants used in the DW_AT_visibility attribute.

See Section 7.10, Table 7.15.

Implementations

impl DwVis

fn static_string(self: &Self) -> Option<&'static str>

impl Clone for DwVis

fn clone(self: &Self) -> DwVis

impl Copy for DwVis

impl Debug for DwVis

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Display for DwVis

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result<(), Error>

impl Eq for DwVis

impl Freeze for DwVis

impl Hash for DwVis

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl Ord for DwVis

fn cmp(self: &Self, other: &DwVis) -> Ordering

impl PartialEq for DwVis

fn eq(self: &Self, other: &DwVis) -> bool

impl PartialOrd for DwVis

fn partial_cmp(self: &Self, other: &DwVis) -> Option<Ordering>

impl RefUnwindSafe for DwVis

impl Send for DwVis

impl StructuralPartialEq for DwVis

impl Sync for DwVis

impl Unpin for DwVis

impl UnsafeUnpin for DwVis

impl UnwindSafe for DwVis

impl<T> Any for DwVis

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for DwVis

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for DwVis

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for DwVis

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for DwVis

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for DwVis

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> ToString for DwVis

fn to_string(self: &Self) -> String

impl<T, U> Into for DwVis

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for DwVis

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for DwVis

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>