Struct gimli::read::RngListIter[−][src]

pub struct RngListIter<R: Reader> { /* fields omitted */ }

An iterator over an address range list.

This iterator internally handles processing of base addresses and different entry types. Thus, it only returns range entries that are valid and already adjusted for the base address.

Implementations

impl<R: Reader> RngListIter<R>[src]

pub fn next(&mut self) -> Result<Option<Range>>[src]

Advance the iterator to the next range.