ConvertSplitUnitSection

Struct ConvertSplitUnitSection 

pub struct ConvertSplitUnitSection<'a, R: Reader<Offset = usize>> { /* private fields */ }
The state for the conversion of a split .debug_info section.

Created by ConvertUnit::convert_split or ConvertUnit::convert_split_with_filter.

Implementations

Source

impl<'a, R: Reader<Offset = usize>> ConvertSplitUnitSection<'a, R>

pub fn read_unit( &mut self, ) -> ConvertResult<(ConvertUnit<'_, R>, ConvertUnitEntry<'_, R>)>

Read the split unit header and prepare to convert it.

Returns a ConvertUnit for the unit, and a ConvertUnitEntry for the root DIE.

See ConvertUnit for an example of the unit conversion.