Struct DwAte
struct DwAte(2935)
The encodings of the constants used in the DW_AT_encoding attribute.
See Section 7.8, Table 7.11.
Implementations
impl DwAte
fn static_string(self: &Self) -> Option<&'static str>
impl Clone for DwAte
fn clone(self: &Self) -> DwAte
impl Copy for DwAte
impl Debug for DwAte
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for DwAte
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result<(), Error>
impl Eq for DwAte
impl Freeze for DwAte
impl Hash for DwAte
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl Ord for DwAte
fn cmp(self: &Self, other: &DwAte) -> Ordering
impl PartialEq for DwAte
fn eq(self: &Self, other: &DwAte) -> bool
impl PartialOrd for DwAte
fn partial_cmp(self: &Self, other: &DwAte) -> Option<Ordering>
impl RefUnwindSafe for DwAte
impl Send for DwAte
impl StructuralPartialEq for DwAte
impl Sync for DwAte
impl Unpin for DwAte
impl UnsafeUnpin for DwAte
impl UnwindSafe for DwAte
impl<T> Any for DwAte
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for DwAte
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for DwAte
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for DwAte
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for DwAte
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for DwAte
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for DwAte
fn to_string(self: &Self) -> String
impl<T, U> Into for DwAte
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for DwAte
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for DwAte
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>