Struct DwCc
struct DwCc(3424)
The encodings of the constants used in the DW_AT_calling_convention attribute.
See Section 7.15, Table 7.19.
Implementations
impl DwCc
fn static_string(self: &Self) -> Option<&'static str>
impl Clone for DwCc
fn clone(self: &Self) -> DwCc
impl Copy for DwCc
impl Debug for DwCc
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for DwCc
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result<(), Error>
impl Eq for DwCc
impl Freeze for DwCc
impl Hash for DwCc
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl Ord for DwCc
fn cmp(self: &Self, other: &DwCc) -> Ordering
impl PartialEq for DwCc
fn eq(self: &Self, other: &DwCc) -> bool
impl PartialOrd for DwCc
fn partial_cmp(self: &Self, other: &DwCc) -> Option<Ordering>
impl RefUnwindSafe for DwCc
impl Send for DwCc
impl StructuralPartialEq for DwCc
impl Sync for DwCc
impl Unpin for DwCc
impl UnsafeUnpin for DwCc
impl UnwindSafe for DwCc
impl<T> Any for DwCc
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for DwCc
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for DwCc
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for DwCc
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for DwCc
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for DwCc
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for DwCc
fn to_string(self: &Self) -> String
impl<T, U> Into for DwCc
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for DwCc
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for DwCc
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>