Struct DwDs
struct DwDs(3041)
The encodings of the constants used in the DW_AT_decimal_sign attribute.
See Section 7.8, Table 7.12.
Implementations
impl DwDs
fn static_string(self: &Self) -> Option<&'static str>
impl Clone for DwDs
fn clone(self: &Self) -> DwDs
impl Copy for DwDs
impl Debug for DwDs
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for DwDs
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result<(), Error>
impl Eq for DwDs
impl Freeze for DwDs
impl Hash for DwDs
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl Ord for DwDs
fn cmp(self: &Self, other: &DwDs) -> Ordering
impl PartialEq for DwDs
fn eq(self: &Self, other: &DwDs) -> bool
impl PartialOrd for DwDs
fn partial_cmp(self: &Self, other: &DwDs) -> Option<Ordering>
impl RefUnwindSafe for DwDs
impl Send for DwDs
impl StructuralPartialEq for DwDs
impl Sync for DwDs
impl Unpin for DwDs
impl UnsafeUnpin for DwDs
impl UnwindSafe for DwDs
impl<T> Any for DwDs
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for DwDs
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for DwDs
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for DwDs
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for DwDs
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for DwDs
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for DwDs
fn to_string(self: &Self) -> String
impl<T, U> Into for DwDs
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for DwDs
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for DwDs
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>