Struct DwDsc
struct DwDsc(3551)
The encodings of the constants used in the DW_AT_discr_list attribute.
See Section 7.18, Table 7.22.
Implementations
impl DwDsc
fn static_string(self: &Self) -> Option<&'static str>
impl Clone for DwDsc
fn clone(self: &Self) -> DwDsc
impl Copy for DwDsc
impl Debug for DwDsc
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for DwDsc
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result<(), Error>
impl Eq for DwDsc
impl Freeze for DwDsc
impl Hash for DwDsc
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl Ord for DwDsc
fn cmp(self: &Self, other: &DwDsc) -> Ordering
impl PartialEq for DwDsc
fn eq(self: &Self, other: &DwDsc) -> bool
impl PartialOrd for DwDsc
fn partial_cmp(self: &Self, other: &DwDsc) -> Option<Ordering>
impl RefUnwindSafe for DwDsc
impl Send for DwDsc
impl StructuralPartialEq for DwDsc
impl Sync for DwDsc
impl Unpin for DwDsc
impl UnsafeUnpin for DwDsc
impl UnwindSafe for DwDsc
impl<T> Any for DwDsc
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for DwDsc
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for DwDsc
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for DwDsc
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for DwDsc
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for DwDsc
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for DwDsc
fn to_string(self: &Self) -> String
impl<T, U> Into for DwDsc
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for DwDsc
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for DwDsc
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>