Struct DwEhPe
struct DwEhPe(4129)
Pointer encoding used by .eh_frame.
The four lower bits describe the format of the pointer, the upper four bits describe how the encoding should be applied.
Defined in <https://refspecs.linuxfoundation.org/LSB_4.0.0/LSB-Core-generic/LSB-Core-generic/dwarfext.html>
Implementations
impl DwEhPe
fn static_string(self: &Self) -> Option<&'static str>
impl DwEhPe
fn format(self: Self) -> DwEhPeGet the pointer encoding's format.
fn application(self: Self) -> DwEhPeGet the pointer encoding's application.
fn is_absent(self: Self) -> boolIs this encoding the absent pointer encoding?
fn is_indirect(self: Self) -> boolIs this coding indirect? If so, its encoded value is the address of the real pointer result, not the pointer result itself.
fn is_valid_encoding(self: Self) -> boolIs this a known, valid pointer encoding?
impl BitOr for DwEhPe
fn bitor(self: Self, rhs: DwEhPe) -> DwEhPe
impl Clone for DwEhPe
fn clone(self: &Self) -> DwEhPe
impl Copy for DwEhPe
impl Debug for DwEhPe
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for DwEhPe
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result<(), Error>
impl Eq for DwEhPe
impl Freeze for DwEhPe
impl Hash for DwEhPe
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl Ord for DwEhPe
fn cmp(self: &Self, other: &DwEhPe) -> Ordering
impl PartialEq for DwEhPe
fn eq(self: &Self, other: &DwEhPe) -> bool
impl PartialOrd for DwEhPe
fn partial_cmp(self: &Self, other: &DwEhPe) -> Option<Ordering>
impl RefUnwindSafe for DwEhPe
impl Send for DwEhPe
impl StructuralPartialEq for DwEhPe
impl Sync for DwEhPe
impl Unpin for DwEhPe
impl UnsafeUnpin for DwEhPe
impl UnwindSafe for DwEhPe
impl<T> Any for DwEhPe
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for DwEhPe
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for DwEhPe
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for DwEhPe
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for DwEhPe
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for DwEhPe
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for DwEhPe
fn to_string(self: &Self) -> String
impl<T, U> Into for DwEhPe
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for DwEhPe
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for DwEhPe
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>