Struct DwEnd
struct DwEnd(3084)
The encodings of the constants used in the DW_AT_endianity attribute.
See Section 7.8, Table 7.13.
Implementations
impl DwEnd
fn static_string(self: &Self) -> Option<&'static str>
impl Clone for DwEnd
fn clone(self: &Self) -> DwEnd
impl Copy for DwEnd
impl Debug for DwEnd
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for DwEnd
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result<(), Error>
impl Eq for DwEnd
impl Freeze for DwEnd
impl Hash for DwEnd
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl Ord for DwEnd
fn cmp(self: &Self, other: &DwEnd) -> Ordering
impl PartialEq for DwEnd
fn eq(self: &Self, other: &DwEnd) -> bool
impl PartialOrd for DwEnd
fn partial_cmp(self: &Self, other: &DwEnd) -> Option<Ordering>
impl RefUnwindSafe for DwEnd
impl Send for DwEnd
impl StructuralPartialEq for DwEnd
impl Sync for DwEnd
impl Unpin for DwEnd
impl UnsafeUnpin for DwEnd
impl UnwindSafe for DwEnd
impl<T> Any for DwEnd
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for DwEnd
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for DwEnd
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for DwEnd
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for DwEnd
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for DwEnd
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for DwEnd
fn to_string(self: &Self) -> String
impl<T, U> Into for DwEnd
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for DwEnd
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for DwEnd
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>