Struct DwId
struct DwId(3382)
The encodings of the constants used in the DW_AT_identifier_case attribute.
See Section 7.14, Table 7.18.
Implementations
impl DwId
fn static_string(self: &Self) -> Option<&'static str>
impl Clone for DwId
fn clone(self: &Self) -> DwId
impl Copy for DwId
impl Debug for DwId
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for DwId
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result<(), Error>
impl Eq for DwId
impl Freeze for DwId
impl Hash for DwId
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl Ord for DwId
fn cmp(self: &Self, other: &DwId) -> Ordering
impl PartialEq for DwId
fn eq(self: &Self, other: &DwId) -> bool
impl PartialOrd for DwId
fn partial_cmp(self: &Self, other: &DwId) -> Option<Ordering>
impl RefUnwindSafe for DwId
impl Send for DwId
impl StructuralPartialEq for DwId
impl Sync for DwId
impl Unpin for DwId
impl UnsafeUnpin for DwId
impl UnwindSafe for DwId
impl<T> Any for DwId
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for DwId
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for DwId
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for DwId
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for DwId
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for DwId
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for DwId
fn to_string(self: &Self) -> String
impl<T, U> Into for DwId
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for DwId
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for DwId
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>