Struct DwInl
struct DwInl(3469)
The encodings of the constants used in the DW_AT_inline attribute.
See Section 7.16, Table 7.20.
Implementations
impl DwInl
fn static_string(self: &Self) -> Option<&'static str>
impl Clone for DwInl
fn clone(self: &Self) -> DwInl
impl Copy for DwInl
impl Debug for DwInl
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for DwInl
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result<(), Error>
impl Eq for DwInl
impl Freeze for DwInl
impl Hash for DwInl
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl Ord for DwInl
fn cmp(self: &Self, other: &DwInl) -> Ordering
impl PartialEq for DwInl
fn eq(self: &Self, other: &DwInl) -> bool
impl PartialOrd for DwInl
fn partial_cmp(self: &Self, other: &DwInl) -> Option<Ordering>
impl RefUnwindSafe for DwInl
impl Send for DwInl
impl StructuralPartialEq for DwInl
impl Sync for DwInl
impl Unpin for DwInl
impl UnsafeUnpin for DwInl
impl UnwindSafe for DwInl
impl<T> Any for DwInl
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for DwInl
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for DwInl
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for DwInl
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for DwInl
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for DwInl
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for DwInl
fn to_string(self: &Self) -> String
impl<T, U> Into for DwInl
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for DwInl
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for DwInl
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>