Struct DwLle
struct DwLle(2993)
The encodings of the constants used in location list entries.
See Section 7.7.3, Table 7.10.
Implementations
impl DwLle
fn static_string(self: &Self) -> Option<&'static str>
impl Clone for DwLle
fn clone(self: &Self) -> DwLle
impl Copy for DwLle
impl Debug for DwLle
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for DwLle
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result<(), Error>
impl Eq for DwLle
impl Freeze for DwLle
impl Hash for DwLle
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl Ord for DwLle
fn cmp(self: &Self, other: &DwLle) -> Ordering
impl PartialEq for DwLle
fn eq(self: &Self, other: &DwLle) -> bool
impl PartialOrd for DwLle
fn partial_cmp(self: &Self, other: &DwLle) -> Option<Ordering>
impl RefUnwindSafe for DwLle
impl Send for DwLle
impl StructuralPartialEq for DwLle
impl Sync for DwLle
impl Unpin for DwLle
impl UnsafeUnpin for DwLle
impl UnwindSafe for DwLle
impl<T> Any for DwLle
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for DwLle
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for DwLle
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for DwLle
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for DwLle
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for DwLle
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for DwLle
fn to_string(self: &Self) -> String
impl<T, U> Into for DwLle
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for DwLle
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for DwLle
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>