Struct DwLnct
struct DwLnct(3771)
The encodings for the line number header entry formats.
See Section 7.22, Table 7.27.
Implementations
impl DwLnct
fn static_string(self: &Self) -> Option<&'static str>
impl Clone for DwLnct
fn clone(self: &Self) -> DwLnct
impl Copy for DwLnct
impl Debug for DwLnct
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for DwLnct
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result<(), Error>
impl Eq for DwLnct
impl Freeze for DwLnct
impl Hash for DwLnct
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl Ord for DwLnct
fn cmp(self: &Self, other: &DwLnct) -> Ordering
impl PartialEq for DwLnct
fn eq(self: &Self, other: &DwLnct) -> bool
impl PartialOrd for DwLnct
fn partial_cmp(self: &Self, other: &DwLnct) -> Option<Ordering>
impl RefUnwindSafe for DwLnct
impl Send for DwLnct
impl StructuralPartialEq for DwLnct
impl Sync for DwLnct
impl Unpin for DwLnct
impl UnsafeUnpin for DwLnct
impl UnwindSafe for DwLnct
impl<T> Any for DwLnct
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for DwLnct
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for DwLnct
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for DwLnct
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for DwLnct
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for DwLnct
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for DwLnct
fn to_string(self: &Self) -> String
impl<T, U> Into for DwLnct
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for DwLnct
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for DwLnct
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>