Enum Error
enum Error
An error that occurred when parsing.
Variants
-
Io An I/O error occurred while reading.
-
PcRelativePointerButSectionBaseIsUndefined Found a PC relative pointer, but the section base is undefined.
-
TextRelativePointerButTextBaseIsUndefined Found a
.textrelative pointer, but the.textbase is undefined.-
DataRelativePointerButDataBaseIsUndefined Found a data relative pointer, but the data base is undefined.
-
FuncRelativePointerInBadContext Found a function relative pointer in a context that does not have a function base.
-
CannotParseOmitPointerEncoding Cannot parse a pointer with a
DW_EH_PE_omitencoding.-
BadUnsignedLeb128 An error parsing an unsigned LEB128 value.
-
BadSignedLeb128 An error parsing a signed LEB128 value.
-
AbbreviationTagZero An abbreviation declared that its tag is zero, but zero is reserved for null records.
-
AttributeFormZero An attribute specification declared that its form is zero, but zero is reserved for null records.
-
BadHasChildren The abbreviation's has-children byte was not one of
DW_CHILDREN_{yes,no}.-
BadLength The specified length is impossible.
-
UnknownForm(constants::DwForm) Found an unknown
DW_FORM_*type.-
ExpectedZero Expected a zero, found something else.
-
DuplicateAbbreviationCode Found an abbreviation code that has already been used.
-
DuplicateArange Found a duplicate arange.
-
UnknownReservedLength Found an unknown reserved length value.
-
UnknownVersion(u64) Found an unknown DWARF version.
-
UnknownAbbreviation(u64) Found a record with an unknown abbreviation code.
-
UnexpectedEof(ReaderOffsetId) Hit the end of input before it was expected.
-
UnexpectedNull Read a null entry before it was expected.
-
UnknownStandardOpcode(constants::DwLns) Found an unknown standard opcode.
-
UnknownExtendedOpcode(constants::DwLne) Found an unknown extended opcode.
-
UnknownLocListsEntry(constants::DwLle) Found an unknown location-lists format.
-
UnknownRangeListsEntry(constants::DwRle) Found an unknown range-lists format.
-
UnsupportedAddressSize(u8) The specified address size is not supported.
-
UnsupportedOffsetSize(u8) The specified offset size is not supported.
-
UnsupportedFieldSize(u8) The specified field size is not supported.
-
MinimumInstructionLengthZero The minimum instruction length must not be zero.
-
MaximumOperationsPerInstructionZero The maximum operations per instruction must not be zero.
-
LineRangeZero The line range must not be zero.
-
OpcodeBaseZero The opcode base must not be zero.
-
BadUtf8 Found an invalid UTF-8 string.
-
NotCieId Expected to find the CIE ID, but found something else.
-
NotCiePointer Expected to find a pointer to a CIE, but found the CIE ID instead.
-
NotFdePointer Expected to find a pointer to an FDE, but found a CIE instead.
-
BadBranchTarget(u64) Invalid branch target for a DW_OP_bra or DW_OP_skip.
-
InvalidPushObjectAddress DW_OP_push_object_address used but no address passed in.
-
NotEnoughStackItems Not enough items on the stack when evaluating an expression.
-
TooManyIterations Too many iterations to compute the expression.
-
InvalidExpression(constants::DwOp) An unrecognized operation was found while parsing a DWARF expression.
-
UnsupportedEvaluation An unsupported operation was found while evaluating a DWARF expression.
-
InvalidPiece The expression had a piece followed by an expression terminator without a piece.
-
InvalidExpressionTerminator(u64) An expression-terminating operation was followed by something other than the end of the expression or a piece operation.
-
DivisionByZero Division or modulus by zero when evaluating an expression.
-
TypeMismatch An expression operation used mismatching types.
-
IntegralTypeRequired An expression operation required an integral type but saw a floating point type.
-
UnsupportedTypeOperation An expression operation used types that are not supported.
-
InvalidShiftExpression The shift value in an expression must be a non-negative integer.
-
InvalidDerefSize(u8) The size of a deref expression must not be larger than the size of an address.
-
UnknownCallFrameInstruction(constants::DwCfa) An unknown DW_CFA_* instruction.
-
InvalidAddressRange The end of an address range was before the beginning.
-
AddressOverflow An address calculation overflowed.
This is returned in cases where the address is expected to be larger than a previous address, but the calculation overflowed.
-
CfiInstructionInInvalidContext Encountered a call frame instruction in a context in which it is not valid.
-
PopWithEmptyStack When evaluating call frame instructions, found a
DW_CFA_restore_statestack pop instruction, but the stack was empty, and had nothing to pop.-
NoUnwindInfoForAddress Do not have unwind info for the given address.
-
UnsupportedOffset An offset value was larger than the maximum supported value.
-
UnknownPointerEncoding(constants::DwEhPe) The given pointer encoding is either unknown or invalid.
-
NoEntryAtGivenOffset Did not find an entry at the given offset.
-
OffsetOutOfBounds The given offset is out of bounds.
-
UnknownAugmentation Found an unknown CFI augmentation.
-
UnsupportedPointerEncoding We do not support the given pointer encoding yet.
-
UnsupportedRegister(u64) Registers larger than
u16are not supported.-
TooManyRegisterRules The CFI program defined more register rules than we have storage for.
-
StackFull Attempted to push onto the CFI or evaluation stack, but it was already at full capacity.
-
VariableLengthSearchTable The
.eh_frame_hdrbinary search table claims to be variable-length encoded, which makes binary search impossible.-
UnsupportedUnitType The
DW_UT_*value for this unit is not supported yet.-
UnsupportedAddressIndex Ranges using AddressIndex are not supported yet.
-
UnsupportedSegmentSize Nonzero segment selector sizes aren't supported yet.
-
MissingUnitDie A compilation unit or type unit is missing its top level DIE.
-
UnsupportedAttributeForm A DIE attribute used an unsupported form.
-
MissingFileEntryFormatPath Missing DW_LNCT_path in file entry format.
-
ExpectedStringAttributeValue Expected an attribute value to be a string form.
-
InvalidImplicitConst DW_FORM_implicit_constused in an invalid context.-
InvalidIndexSectionCount Invalid section count in
.dwpindex.-
InvalidIndexSlotCount Invalid slot count in
.dwpindex.-
InvalidIndexRow Invalid hash row in
.dwpindex.-
UnknownIndexSection(constants::DwSect) Unknown section type in
.dwpindex.-
UnknownIndexSectionV2(constants::DwSectV2) Unknown section type in version 2
.dwpindex.
Implementations
impl Error
fn description(self: &Self) -> &strA short description of the error.
impl Clone for Error
fn clone(self: &Self) -> Error
impl Copy for Error
impl Debug for Error
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for Error
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result<(), Error>
impl Eq for Error
impl Freeze for Error
impl PartialEq for Error
fn eq(self: &Self, other: &Error) -> bool
impl RefUnwindSafe for Error
impl Send for Error
impl StructuralPartialEq for Error
impl Sync for Error
impl Unpin for Error
impl UnsafeUnpin for Error
impl UnwindSafe for Error
impl<T> Any for Error
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Error
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Error
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Error
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Error
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Error
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for Error
fn to_string(self: &Self) -> String
impl<T, U> Into for Error
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Error
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Error
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>