Trait Section
trait Section<R>: From<R>
A convenience trait for loading DWARF sections from object files. To be used like:
use ;
let buf = ;
let reader = new;
let loader = ;
let debug_info: = load.unwrap;
Required Methods
fn id() -> SectionIdReturns the section id for this type.
fn reader(self: &Self) -> &R where R: ReaderReturns the
Readerfor this section.
Provided Methods
fn section_name() -> &'static strReturns the ELF section name for this type.
fn dwo_section_name() -> Option<&'static str>Returns the ELF section name (if any) for this type when used in a dwo file.
fn xcoff_section_name() -> Option<&'static str>Returns the XCOFF section name (if any) for this type when used in a XCOFF file.
fn load<F, E>(f: F) -> Result<Self, E> where F: FnOnce(SectionId) -> Result<R, E>Try to load the section using the given loader function.
fn dwp_range(self: &Self, offset: u32, size: u32) -> Result<Self> where R: ReaderReturns the subrange of the section that is the contribution of a unit in a
.dwpfile.fn lookup_offset_id(self: &Self, id: ReaderOffsetId) -> Option<(SectionId, <R as >::Offset)> where R: ReaderReturns the
Readerfor this section.
Implementors
impl<R> Section for DebugLineStr<R>impl<R: Reader> Section for DebugPubNames<R>impl<R> Section for DebugInfo<R>impl<R> Section for DebugStr<R>impl<R: Reader> Section for DebugFrame<R>impl<R: Reader> Section for EhFrameHdr<R>impl<R> Section for DebugLocLists<R>impl<R> Section for DebugLoc<R>impl<R: Reader> Section for EhFrame<R>impl<R> Section for DebugTuIndex<R>impl<R> Section for DebugAranges<R>impl<R> Section for DebugStrOffsets<R>impl<R> Section for DebugCuIndex<R>impl<R> Section for DebugAddr<R>impl<R> Section for DebugTypes<R>impl<R: Reader> Section for DebugPubTypes<R>impl<R> Section for DebugLine<R>impl<R> Section for DebugAbbrev<R>impl<R> Section for DebugRngLists<R>impl<R> Section for DebugRanges<R>